referrerpolicy=no-referrer-when-downgrade

AccountSigner

Type Alias AccountSigner 

pub type AccountSigner = MultiSigner;
Public key of the chain account that may be used to verify signatures.

Aliased Type

pub enum AccountSigner {
    Ed25519(CryptoBytes<32, (PublicTag, Ed25519Tag)>),
    Sr25519(CryptoBytes<32, Sr25519PublicTag>),
    Ecdsa(CryptoBytes<33, (PublicTag, EcdsaTag)>),
    Eth(CryptoBytes<33, (PublicTag, EcdsaKeccakTag)>),
}

Variants



Ed25519(CryptoBytes<32, (PublicTag, Ed25519Tag)>)

An Ed25519 identity.



Sr25519(CryptoBytes<32, Sr25519PublicTag>)

An Sr25519 identity.



Ecdsa(CryptoBytes<33, (PublicTag, EcdsaTag)>)

An SECP256k1/ECDSA identity (actually, the Blake2 hash of the compressed pub key).



Eth(CryptoBytes<33, (PublicTag, EcdsaKeccakTag)>)

Same as Ecdsa but its account id is derived based off its eth address instead of its pubkey.

This is important so that the address matches the address to address mapping in pallet_revive. This means that the same public key controls two accounts. But this is already the case due to pallet_revive’s address mapping.